<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Leads_model extends CI_Model {

	public function fetch_load_leads_data($searchValue = null, $user_id, $role_id)
	{
		
		if ($role_id == 1)
		{
			$this->db->select('L.id, L.date_time, L.stage, L.developer_name, L.project_name, L.full_name, L.full_number, L.email_address, L.source, L.looking_for, U.first_name, L.notify_status');
			$this->db->from('lead_generate L');
			$this->db->join('lead_assign A', 'L.id = A.lead_id', 'left');
			$this->db->join('users U', 'U.id = A.user_id', 'left');
			$this->db->group_by('L.id');

			if (isset($searchValue))
			{
				$this->db->group_start();
				$this->db->or_like('L.id', $searchValue);
				$this->db->or_like('project_name', $searchValue);
				$this->db->or_like('developer_name', $searchValue);
				$this->db->or_like('full_name', $searchValue);
				$this->db->or_like('stage', $searchValue);
				$this->db->or_like('source', $searchValue);
				$this->db->or_like('U.first_name', $searchValue);
				$this->db->group_end();
			}

			
			// $this->db->where('A.user_id', $user_id);	
		}else{
			$this->db->select('L.id, L.date_time, L.stage, L.developer_name, L.project_name, L.full_name, L.full_number, L.email_address, L.source, L.looking_for, A.notify_status');
			$this->db->from('lead_assign A');
			$this->db->join('lead_generate L', 'L.id = A.lead_id');
			// $this->db->join('users U', 'U.id = A.assigned_by');
			$this->db->where('A.user_id', $user_id);
			// $this->db->order_by('id', 'desc');

			if (isset($searchValue))
			{
				$this->db->group_start();
				$this->db->or_like('L.id', $searchValue);
				$this->db->or_like('project_name', $searchValue);
				$this->db->or_like('developer_name', $searchValue);
				$this->db->or_like('full_name', $searchValue);
				$this->db->or_like('stage', $searchValue);
				$this->db->or_like('source', $searchValue);
				$this->db->group_end();
			}
		}	

		

		if (isset($_POST['order']))
		{
			$order_column = array('id','date_time', 'stage', 'developer_name', 'project_name', 'full_number', 'email_address', 'source', 'first_name', null);
			$this->db->order_by($order_column[$_POST['order']['0']['column']], $_POST['order']['0']['dir']);
		}else{
			$this->db->order_by('id', 'DESC');
		}
	}

	public function make_datatables($searchValue = null, $user_id, $role_id)
	{
		$this->fetch_load_leads_data($searchValue, $user_id, $role_id);
		if ($_POST['length'] != -1)
		{
			$this->db->limit($_POST['length'], $_POST['start']);
		}

		$query = $this->db->get();
		return $query->result();
	}

	public function get_filtered_data($searchValue = null, $user_id, $role_id)
	{
		$this->fetch_load_leads_data($searchValue, $user_id, $role_id);
		$query = $this->db->get();
		return $query->num_rows();
	}

	public function get_all_data()
	{
		$this->db->select('*');
		$this->db->from('lead_generate');
		return $this->db->count_all_results();
	}

	public function lead_info($id)
	{
		$this->db->where('id', $id);
		$d = $this->db->get('lead_generate');
		return $d->row();
	}

	public function loadUsers($search)
	{
		$this->db->group_start();
		$this->db->or_like('first_name', $search);
		$this->db->or_like('last_name', $search);
		$this->db->group_end();
		$d = $this->db->get('users');
		return $d->result();
	}

	public function loadSources()
	{
		$this->db->group_by('source');
		$d = $this->db->get('lead_generate');
		
		$source=[];
		foreach ($d->result() as $key => $value) {
			$source[$value->source] = $value->source;
		}
		return $source;
	}

	public function loadUnitTypes()
	{
		$d = $this->db->get('lead_unit_type');
		
		$types['']="";
		foreach ($d->result() as $key => $value) {
			$types[$value->id] = $value->unit_type;
		}
		return $types;
	}

	public function update_lead($lead_info)
	{
		$this->db->where('id', $lead_info['id']);
		if ($this->db->update('lead_generate', $lead_info))
		{
			return true;
		}else{
			return false;
		}
	}

	public function insert_comment($lead_comment)
	{

		$this->db->insert('lead_comments', $lead_comment);
		
	}

	

	public function getComments($id)
	{
		$this->db->where('lead_id', $id);
		$d = $this->db->get('lead_comments');
		return $d->result();
	}

	public function comment_info($id)
	{
		$this->db->where('id', $id);
		$d = $this->db->get('lead_comments');
		return $d->row();
	}

	public function update_comment($comment)
	{
		unset($comment['e_lead_id']);
		$id = $comment['id'];
		$this->db->where('id', $id);
		if ($this->db->update('lead_comments', $comment))
		{
			return true;
		}else{
			return false;
		}
	}

	public function update_stage_add($lead_comment)
	{
		$id = $lead_comment['lead_id'];
		$this->db->where('id', $id);
		$this->db->set('stage', $lead_comment['stage']);
		$this->db->update('lead_generate');		
	}

	public function update_stage($comment)
	{

		$lead_id = $comment['e_lead_id'];
		$this->db->where('id', $lead_id);
		$this->db->set('stage', $comment['stage']);
		if ($this->db->update('lead_generate'))
		{
			return true;
		}else{
			return false;
		}
	}

	public function assigned_lead($data)
	{
		if ($this->db->insert('lead_assign', $data))
		{
			return true;
		}else{
			return false;
		}
	}

	// public function get_new_notifications() {
    //     // Fetch new notifications from the database
    //     // Adjust the query to fit your database schema
    //     $this->db->where('notify_status', 'new');
    //     $query = $this->db->get('lead_generate');
    //     return $query->result();
    // }

    // public function mark_notifications_as_read($notification_ids) {
    //     $this->db->where_in('id', $notification_ids);
    //     $this->db->update('lead_generate', ['notify_status' => 'read']);
    // }

    public function count_new_leads() {
        $this->db->where('notify_status', 'new');
        if ($this->logged_in_role_id  == 1)
        {
        	$this->db->from('lead_generate');
        }else{
        	$this->db->from('lead_assign');
        }
        return $this->db->count_all_results();
    }

    public function update_notify_status($id)
	{
		
		if ($this->logged_in_role_id  == 1)
		{
			$this->db->where('id', $id);
			$this->db->set('notify_status', 'read');
			$this->db->update('lead_generate');
		}else{
			$this->db->where('lead_id', $id);
			$this->db->set('notify_status', 'read');
			$this->db->update('lead_assign');
		}

	}



}
